from PIL import Image
import imagehash

import unittest


class ReporterTestCase(unittest.TestCase):

    false_screen_shot = "false_screenshot_reden.png"
    true_screen_shot = "screenshot_reden.png"
    base_screen_shot = "base_line_screenshot_reden.png"

    hash_method_dict = {
        'dhash': imagehash.dhash,
        'phash': imagehash.phash,
        'ahash': imagehash.average_hash,
        'crhash' : imagehash.crop_resistant_hash,
        'whash' : imagehash.whash,
        'dvhash' : imagehash.dhash_vertical,
    }


    def test_should_be_indentical_with_phash(self):
        """
        Test if the phash method behaves correct against baseline
        """
        self.use_image_hashing(first=self.base_screen_shot, second=self.true_screen_shot,
                       name_executing_method=self._testMethodName, hash_method="phash")

    def test_indentical_with_phash(self):
        """
        Test if the phash method is reflexive
        """
        self.use_image_hashing(first=self.base_screen_shot, second=self.base_screen_shot,
                       name_executing_method=self._testMethodName, hash_method="phash")

    def test_should_be_different_with_phash(self):
        """
         Test if the phash method assert false if there are differences against baseline
        """
        self.use_image_hashing(first=self.base_screen_shot, second=self.false_screen_shot,
                       name_executing_method=self._testMethodName, hash_method="phash", is_true=False)


    def use_image_hashing(self, first, second, name_executing_method="", hash_method="dhash", is_true=True):
        hash_base_line = self.hash_method_dict[hash_method](Image.open(first))
        hash_compare_base_line = self.hash_method_dict[hash_method](Image.open(second))

        if is_true:
            self.assertTrue(hash_base_line == hash_compare_base_line)
        else:
            self.assertFalse(hash_base_line == hash_compare_base_line)


if __name__ == '__main__':
    unittest.main()


import unittest
from nemonet.engines.cache_store import KeyValueStore

class CachingTestCase(unittest.TestCase):

    def setUp(self) -> None:
        self.key_value_Store = KeyValueStore()

    def tearDown(self) -> None:
        self.key_value_Store.close()

    def test_add_get(self):
        self.key_value_Store.add("key","value")
        value = self.key_value_Store.get_value_as_str("key")
        self.assertTrue( value == "value" )

    def test_add_get_aigu(self):
        self.key_value_Store.add("key","valeé")
        value = self.key_value_Store.get_value_as_str("key")
        self.assertTrue( value == "valeé" )

    def test_add_get_umlaut(self):
        self.key_value_Store.add("key","valö")
        value = self.key_value_Store.get_value_as_str("key")
        self.assertTrue( value == "valö" )

    def test_add_get_grave(self):
        self.key_value_Store.add("key","valè")
        value = self.key_value_Store.get_value_as_str("key")
        self.assertTrue( value == "valè" )

    def test_add_get_circonflexe(self):
        self.key_value_Store.add("key","valèç")
        value = self.key_value_Store.get_value_as_str("key")
        self.assertTrue( value == "valèç" )


if __name__ == '__main__':
    unittest.main()



# Created by Jan Rummens at 18/01/2021
import unittest
import json
from requests.auth import HTTPBasicAuth
import requests

from nemonet.plugin.handle_zephyr import merge_json_xml, set_jira_item_status

xml_file="""<graph>
    <nodes>
        <node name="selenium"/>
        <node name="phrase"/>
        <node name="waiting"/>
    </nodes>
    <edges>
        <edge from="selenium" to="phrase"/>
        <edge from="phrase" to="waiting"/>
    </edges>
    <actions>
        <action xpath="" type="OPENURL" nodename="selenium" value="https://www.selenium.dev/"/>
        <action xpath="//*[@id='gsc-i-id1']" type="TEXTABLE-ENTER" nodename="phrase" value="computer vision"/>
        <action xpath="" type="WAIT" nodename="waiting" value="5"/>
    </actions>
</graph>"""

json_file="""{
    "plugin": {
        "zephyr": {
            "project" : "FORE",
            "summary" : "summary",
            "description" : "description"
        }
    }
}"""

class MyTestCase(unittest.TestCase):

    def setUp(self):
        fp = open("dummy.xml","w")
        fp.write(xml_file)
        fp.close()
        fp = open("dummy.json","w")
        fp.write(json_file)
        fp.close()

    def test_read_json(self):
        data = None
        with open('dummy.json') as json_file:
            data = json.load(json_file)
            json_file.close()

        self.assertTrue( data['plugin']['zephyr']['project'] == "FORE" )
        self.assertTrue( data['plugin']['zephyr']['summary'] == "summary")
        self.assertTrue( data['plugin']['zephyr']['description'] == "description")


    def test_merge_xml_json(self):
        merge_json_xml("dummy")
        # TODO check the files (json, xml) with assert statements

if __name__ == '__main__':
    unittest.main()



# Created by Jan Rummens at 12/01/2021
import unittest
from nemonet.runner.vision_runner import Runner

class CommandsTestCase(unittest.TestCase):

    def setUp(self) -> None:
        self.runner = Runner(runner_config="runner_config.json")

    def tearDown(self) -> None:
        self.runner = None

    def test_open_formatted_url(self):
        self.runner.execute_scenario("commands-reformat-url")

if __name__ == '__main__':
    unittest.main()



# Created by Jan Rummens at 12/01/2021
import unittest
from nemonet.runner.vision_runner import Runner

class CommandsTestCase(unittest.TestCase):

    def setUp(self) -> None:
        self.runner = Runner(runner_config="runner_config.json")

    def tearDown(self) -> None:
        self.runner = None

    def test_chrome_options(self):
        self.runner.execute_scenario("dummy")

    def test_save_records(self):
        self.runner.execute_scenario("commands-save-records")

    def test_double_click(self):
        self.runner.execute_scenario("commands-double-mouse-click")

    def test_drag_and_drop(self):
        self.runner.execute_scenario("commands-drag-and-drop")

    def test_drag_and_drop_mouse(self):
        self.runner.execute_scenario("commands-drag-and-drop-mouse")

    def test_drag_and_drop_offset(self):
        self.runner.execute_scenario("commands-drag-and-drop-offset")

    def test_explicit_waits(self):
        self.runner.execute_scenario("commands-explicit-waits")

    def test_remove_html_element(self):
        self.runner.execute_scenario("commands-remove-html-element")

    def test_right_mouse(self):
        self.runner.execute_scenario("command-right-mouse")

    def test_tabs(self):
        self.runner.execute_scenario("command-tabs")

    def test_current_pos(self):
        self.runner.execute_scenario("command-current-pos")

    def test_site_settings(self):
        # chrome only
        self.runner.execute_scenario("commands-site-settings")

if __name__ == '__main__':
    unittest.main()



'''
Created on 13 feb. 2018

@author: ex03210
'''
import logging

from selenium.webdriver.support import expected_conditions as ec
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.common.by import By
from selenium.webdriver.common.action_chains import ActionChains
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.support.ui import Select
from selenium.common.exceptions import ElementNotVisibleException

from nemonet.seleniumwebdriver.page_capture import PageCapturing
from nemonet.engines.cache_store import KeyValueStore

import random
import string
import time

from nemonet.cvision.computer_vision import ComputerVision


class Command(object):
    """
        All kind of selenium actions
    """


    def __init__(self, driver=None):
        """Constructor"""
        self.driver = driver
        self._wait = WebDriverWait(self.driver, 60)
        self.logger = logging.getLogger('vision_logger')
        self.logger.setLevel(logging.DEBUG)
        fh = logging.FileHandler('vision.log')
        formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
        fh.setFormatter(formatter)
        self.logger.addHandler(fh)

    def add_browser_tabs(self, nbr_of_tabs=1):
        self.logger.debug(self.driver.current_window_handle)
        for nbr in range(nbr_of_tabs):
            tab_name = "TAB_" + str(nbr)
            self.driver.execute_script("window.open('about:blank', '%s');" % ( tab_name ) )
            time.sleep(0.5)
            self.driver.switch_to.window(tab_name)
            self.logger.debug(self.driver.current_window_handle)

    def goto_browser_tab(self, tab_nbr=1):
        handles = self.driver.window_handles
        self.logger.debug(handles)
        self.driver.switch_to.window( handles[tab_nbr] )

    def goto_current_browser_tab(self):
        self.driver.switch_to.window( self.driver.current_window_handle )

    def goto_frame(self, frame_nbr):
        self.driver.switch_to.frame(int(frame_nbr))

    def log_current_url(self):
        self.logger.debug(self.driver.current_url)

    def openurl(self, url ):
        self.driver.get(str(url))

    def screenshot(self, filename):
        capture = PageCapturing(self.driver)
        capture.capture_save(file_name_cpatured=filename)

    def element(self, locator):
        element = self._wait.until(ec.element_to_be_clickable(locator), message='Cannot locate {}'.format(locator))
        self.driver.execute_script("arguments[0].scrollIntoView(true);", element)
        return element

    def click(self, locator):
        self.element(locator).click()



    def select_drop_down_by_value(self, select_locator, value):
        Select(self.element(select_locator)).select_by_value(value)

    def select_drop_down_by_text(self, select_locator, text):
        Select(self.element(select_locator)).select_by_visible_text(text)

    def find_element_xpath(self, xpath_str):
        return self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))

    def find_elements_xpath(self, xpath_str):
        return self._wait.until(ec.visibility_of_all_elements_located((By.XPATH, xpath_str)))

    def fill_in_text(self, xpath_str, text):
        # element = WebDriverWait(self.driver, 60 ).until(EC.presence_of_element_located(( By.XPATH, xpathStr )))
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click()
        actions.send_keys(text)
        actions.perform()

    def fill_in_text_no_action_chain(self, xpath_str, text):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        element.send_keys(text)

    def element_fill_in_text(self, element, text):
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click()
        actions.send_keys(text)
        actions.perform()

    def enter_text_current_position(self, text=""):
        actions = ActionChains(self.driver)
        actions.send_keys(text)
        actions.perform()

    def enter_text_current_position_stamp(self, text=""):
        actions = ActionChains(self.driver)
        text = text + " " + ''.join([random.choice(string.ascii_letters + string.digits) for n in range(32)])
        actions.send_keys(text)
        actions.perform()

    def enter_tab_current_position(self):
        actions = ActionChains(self.driver)
        actions.send_keys(Keys.TAB)
        actions.perform()

    def fill_in_text_enter(self, xpath_str, text):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element)
        actions.click()
        actions.send_keys(text)
        actions.send_keys(Keys.RETURN).perform()

    def clear_fill_in_text(self, xpath_str, text):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        self.driver.execute_script("arguments[0].scrollIntoView();", element)
        self.driver.execute_script("arguments[0].value = '';", "")
        time.sleep(0.25)
        actions = ActionChains(self.driver)
        element.clear()
        actions.move_to_element(element).perform()
        element.clear()
        actions.click()
        actions.send_keys(text)
        actions.perform()

    def clear_fill_in_text_tab(self, xpath_str, text):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        element.clear()
        actions.move_to_element(element).perform()
        actions.click()
        actions.send_keys(text)
        actions.send_keys(Keys.TAB)
        actions.perform()


    def click_xpath(self, xpath_str):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click()
        actions.perform()

    def right_click_xpath(self, xpath_str):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.context_click(element)
        actions.perform()

    def click_css(self, css_str):
        element = self._wait.until(ec.visibility_of_element_located((By.CSS_SELECTOR, css_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click()
        actions.perform()

    def click_element_in_list(self, xpath_str, index):
        element = self._wait.until(ec.visibility_of_all_elements_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element[index]).perform()
        actions.click()
        actions.perform()

    def element_click(self, element):
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click()
        actions.perform()

    def double_click_xpath(self, xpath_str):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.double_click(element)
        actions.perform()

    def drag_and_drop_mouse_xpath(self, xpath_from, xpath_to):
        element_from = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_from)))
        element_to = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_to)))
        actions = ActionChains(self.driver)
        actions.click(element_from).perform()
        time.sleep(0.25)
        actions.click_and_hold(element_from)
        actions.move_to_element(element_to).perform()
        time.sleep(0.25)
        actions.release()
        time.sleep(0.25)
        actions.perform()

    def drag_and_drop_xpath(self, xpath_from, xpath_to):
        element_from = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_from)))
        element_to = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_to)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element_from).perform()
        actions.drag_and_drop(element_from,element_to)
        actions.perform()

    def drag_and_drop_offset_xpath(self, xpath_from, offset_x, offset_y):
        element_from = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_from)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element_from).perform()
        time.sleep(0.25)
        actions.drag_and_drop_by_offset( element_from, offset_x, offset_y)
        time.sleep(0.25)
        actions.perform()

    def remove_html_element(self, css_selector):
        element_css_selector = self._wait.until(ec.presence_of_element_located((By.CSS_SELECTOR, css_selector)))
        time.sleep(0.25)
        self.driver.execute_script("arguments[0].scrollIntoView();", element_css_selector)
        time.sleep(0.25)
        self.driver.execute_script("arguments[0].parentNode.removeChild(arguments[0]);",element_css_selector)


    def __movedDownEnter__(self, xpStr, nbrofMoves):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpStr)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click().perform()
        for i in range(nbrofMoves):
            actions.send_keys(Keys.DOWN)
        actions.perform()
        actions.send_keys(Keys.RETURN).perform()

    def __scrollToTop__(self):
        element = self.driver.find_element_by_tag_name("head")
        self.driver.execute_script("return arguments[0].scrollIntoView(true);", element)

    def scroll_to_element(self, xpath_str):
        element = WebDriverWait(self.driver, 120).until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        self.driver.execute_script("return arguments[0].scrollIntoView(true);", element)

    def __findTextAndClick__(self, text):
        self.driver.find_element_by_xpath("//*[contains(text(), '%s')]" % (text)).click()

    def get_text_xpath(self, xpath_str):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        return element.text

    def get_text_from_element(self, element):
        return element.text

    def __selectFromDropDown__(self, xpathStr, text):
        element = WebDriverWait(self.driver, 120).until(ec.visibility_of_element_located((By.XPATH, xpathStr)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click()
        actions.send_keys(text)
        actions.click()
        actions.perform()

    def select_drop_down_enter(self, xpath_str, text):
        element = self._wait.until(ec.visibility_of_element_located((By.XPATH, xpath_str)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element).perform()
        actions.click()
        actions.send_keys(text)
        actions.click()
        actions.send_keys(Keys.RETURN)
        actions.perform()

    def __selectFromDropDownByValue__(self, xpathStr, value):
        element = Select(WebDriverWait(self.driver, 120).until(ec.visibility_of_element_located((By.XPATH, xpathStr))))
        element.select_by_value(value)

    def wait(self, number_of_seconds):
        time.sleep(number_of_seconds)

    def split_stored_url(self, url_key):
        kv_store = KeyValueStore()
        url = kv_store.get_value_as_str(url_key)
        split_url = url.split('//')[1].split('/')
        counter = 1
        for section in split_url:
            if len(section) > 0:
                url_key_nbr = url_key + "_" + str(counter)
                counter += 1
                kv_store.add(url_key_nbr, section )
        kv_store.close()

    def split_url_and_store(self, key_prefix, value):
        split_url = value.split('//')[1].split('/')
        kv_store = KeyValueStore()
        counter = 1
        for section in split_url:
            if len(section) > 0:
                url_key_nbr = key_prefix + "_" + str(counter)
                counter += 1
                kv_store.add(url_key_nbr, section)
        kv_store.close()


    def format_string_and_store(self, key, value):
        kv_store = KeyValueStore()
        reformated_str = kv_store.replace_formated_key(value)
        kv_store.add(key, reformated_str)
        kv_store.close()

    def store_string(self, key, value):
        kv_store = KeyValueStore()
        kv_store.add(key,value)
        kv_store.close()

    def change_site_settings_with_tabs(self, url, tab_nbr):
        set_back_url = self.driver.current_url
        self.openurl(url)
        actions = ActionChains(self.driver)
        actions.send_keys(Keys.TAB * int(tab_nbr))
        actions.send_keys(Keys.ARROW_DOWN)
        actions.perform()
        time.sleep(0.25)
        self.openurl(set_back_url)


    def executeSequences(self, seq, g):

        for step in g.getSetup():
            self.execute_action(step.getAction())

        pa = seq.get()
        for l in pa:
            #logger.info("Excute sequence=%s" % (str(l)))
            for el in l:
                a = g.getVertex(el).getAction()
                self.execute_action(a)

    def log_action_command(self, action_command):
        key_value_list = []

        key_value_list.append({'type' : action_command.getElementType() })
        key_value_list.append({'xpath': action_command.getXpathStr()})
        key_value_list.append({'value': action_command.getValue()})
        key_value_list.append({'key': action_command.get_key()})
        key_value_list.append({'waitafter': action_command.get_wait_after()})

        command_str=""

        for item in key_value_list:
            key = list(item.keys())[0]
            value = str(list(item.values())[0])
            command_str += "%s=%s " % (key,value)
        self.logger.debug(command_str)

    def execute_action(self, a):
        """
        TODO : error handling
        :param a:
        :return:
        """
        self.log_action_command( a )

        command_type = a.getElementType()

        if command_type == 'CLICKABLE':
            self.click_xpath(a.getXpathStr())
        elif command_type == 'TEXTABLE':
            if a.getValue() == None:
                rStr = ''.join([random.choice(string.ascii_letters + string.digits) for n in range(32)])
            else:
                rStr = a.getValue()
            self.fill_in_text(a.getXpathStr(), rStr)
        elif command_type == 'JSexec':
            self.driver.execute_script(a.getXpathStr())
        elif command_type == 'SELECTABLE':
            self.click_element_in_list(a.getXpathStr(), 2)
        elif command_type == 'OPENURL':
            self.openurl(a.getValue())
        elif command_type == 'SCREENSHOT':
            self.screenshot(a.getValue())
        elif command_type == 'CLEARTEXTABLE':
            if a.getValue() == None:
                rStr = ''.join([random.choice(string.ascii_letters + string.digits) for n in range(32)])
            else:
                rStr = a.getValue()
            self.clear_fill_in_text(a.getXpathStr(), rStr)
        elif command_type == 'CLEARTEXTABLETAB':
            if a.getValue() == None:
                rStr = ''.join([random.choice(string.ascii_letters + string.digits) for n in range(32)])
            else:
                rStr = a.getValue()
            self.clear_fill_in_text_tab(a.getXpathStr(), rStr)
        elif command_type == 'TEXTABLE-ENTER':
            if a.getValue() == None:
                rStr = ''.join([random.choice(string.ascii_letters + string.digits) for n in range(32)])
            else:
                rStr = a.getValue()
            self.fill_in_text_enter(a.getXpathStr(), rStr)
        elif command_type == 'COMPAREPNG':
            arguments = eval(a.getValue())
            filenameA = arguments[0]
            filenameB = arguments[1]
            cv = ComputerVision()
            result = cv.diff(filenameA, filenameB)
            assert result, 'Difference between %s and %s' % (filenameA, filenameB)
        elif command_type == 'COMPAREPNGPHASH':
            arguments = eval(a.getValue())
            filenameA = arguments[0]
            filenameB = arguments[1]
            cv = ComputerVision()
            result = cv.diff_with_phash_image_hash(filenameA, filenameB)
            assert result, 'Difference between %s and %s' % (filenameA, filenameB)
        elif command_type == 'WAIT':
            time.sleep(int(a.getValue()))
        elif command_type == 'SCROLLTOP':
            self.driver.execute_script("window.scrollTo(0,0);")
        elif command_type == 'SCROLLBOTTOM':
            self.driver.execute_script("window.scrollTo(0, document.body.scrollHeight)")
        elif command_type == 'DUMMY':
            #command for testing purposes
            pass
        elif command_type == 'BROWSER_TABS_ADD':
            nbr_of_tabs = int(a.getValue())
            self.add_browser_tabs(nbr_of_tabs)
        elif command_type == 'BROWSER_TABS_GOTO':
            tab_nbr = int(a.getValue())
            self.goto_browser_tab( tab_nbr )
        elif command_type == 'BROWSER_TABS_GOTO_CURRENT':
            self.goto_current_browser_tab()
        elif command_type == "TEXT_CURRENT_POSITION":
            text = a.getValue()
            self.enter_text_current_position( text )
        elif command_type == "TEXT_CURRENT_POSITION_STAMP":
            text = a.getValue()
            self.enter_text_current_position_stamp( text )
        elif command_type == "TAB":
            text = a.getValue()
            self.enter_tab_current_position()
        elif command_type == "LOG_CURRENT_URL":
            self.log_current_url()
        elif command_type == "CLICKABLE_RIGHT":
            self.right_click_xpath(a.getXpathStr())
        elif command_type == "CLICKABLE_DOUBLE":
            self.double_click_xpath(a.getXpathStr())
        elif command_type == "DRAG_AND_DROP":
            from_xpath = a.getXpathStr()
            to_xpath = a.getValue()
            self.drag_and_drop_xpath( from_xpath, to_xpath )
        elif command_type == "DRAG_AND_DROP_MOUSE":
            from_xpath = a.getXpathStr()
            to_xpath = a.getValue()
            self.drag_and_drop_mouse_xpath(from_xpath, to_xpath)
        elif command_type == "GOTO_FRAME":
            self.goto_frame(a.getValue())
        elif command_type == "DRAG_AND_DROP_WITH_OFFSET":
            from_xpath = a.getXpathStr()
            offsets=a.getValue()
            offsets = offsets.split(',')
            self.drag_and_drop_offset_xpath( from_xpath, offsets[0], offsets[1])
        elif command_type == "SWITCH_TO_ALERT_AND_CONFIRM":
            the_alert = self.driver.switch_to.alert
            the_alert.accept()
        elif command_type == "REMOVE_HTML_ELEMENT":
            css_selector = a.getValue()
            self.remove_html_element(css_selector)
        elif command_type == "SAVE_CURRENT_URL":
            kv_store = KeyValueStore()
            kv_store.add( a.get_key(), self.driver.current_url )
            kv_store.close()
        elif command_type == "SPLIT_STORED_URL":
            self.split_stored_url( a.get_key() )
        elif command_type == "FORMAT_STRINGS":
            string_to_format = a.getValue()
            key_for_store = a.get_key()
            self.format_string_and_store(key_for_store, string_to_format)
        elif command_type == "STORE_STRING":
            string_to_store = a.getValue()
            key_for_store = a.get_key()
            self.store_string(key_for_store, string_to_store)
        elif command_type == "SPLIT_URL_AND_STORE":
            string_to_split = a.getValue()
            key_for_store = a.get_key()
            self.split_url_and_store(key_for_store, string_to_split)
        elif command_type == "OPEN_STORED_URL":
            kv_store = KeyValueStore()
            stored_key = a.get_key()
            url = kv_store.get_value_as_str(stored_key)
            self.logger.debug(url)
            self.openurl(url)
        elif command_type == "SELECT_FROM_DROP_DOWN":
            select_xpath = a.getXpathStr()
            some_text = a.getValue()
            self.select_drop_down_by_text((By.XPATH, select_xpath), some_text)
        elif command_type == "SITE_SETTINGS":
            site_setting_url_and_tab_nbr = a.getValue()
            site_setting_url_and_tab_nbr_list = site_setting_url_and_tab_nbr.split('|')
            url = site_setting_url_and_tab_nbr_list[0]
            tab_nbr = site_setting_url_and_tab_nbr_list[1]
            self.change_site_settings_with_tabs(url,tab_nbr)
        else:
            assert False, "unknown command"
        waiting_time = a.get_wait_after()
        time.sleep(waiting_time)

class AbstractPage(Command):

    def __init__(self, driver, sleepTime=20, pollFrequency=1):
        super(AbstractPage, self).__init__(driver)
        self.sleepTime = sleepTime
        self.pollFrequency = pollFrequency

    def WaitUntilLoaded(self):
        aList = self.xPathWaitForList()
        for item in aList:
            wait = WebDriverWait(self.driver, self.sleepTime, poll_frequency=self.pollFrequency,
                                 ignored_exceptions=[ElementNotVisibleException])
            element = wait.until(ec.presence_of_all_elements_located((By.XPATH, item)))
            time.sleep(self.sleepTime)
        return True

    def xPathWaitForList(self):
        raise NotImplementedError()

    def __fillInTextAtIndex__(self, xpathStr, text, index=0):
        element = WebDriverWait(self.driver, 120).until(ec.visibility_of_all_elements_located((By.XPATH, xpathStr)))
        actions = ActionChains(self.driver)
        actions.move_to_element(element[index]).perform()
        actions.click()
        actions.send_keys(text)
        actions.perform()



# Created by Jan Rummens at 21/09/2020
import unittest
import time

from nemonet.screencast.recording import ScreenRecorder


class MyTestCase(unittest.TestCase):

    def setUp(self):
        self.screenRecorder  = ScreenRecorder()
        self.screenRecorder.start()

    def tearDown(self):
        self.screenRecorder.stop()

    def test_something(self):
        time.sleep(2)


if __name__ == '__main__':
    unittest.main()



import unittest

from bs4 import BeautifulSoup

from nemonet.engines.graph import Vertex, Graph, Action

#tests
class Test(unittest.TestCase):

    def setUp(self):
        self.tree = Graph()
        a = Vertex('A')
        b = Vertex('B')
        c = Vertex('C')
        d = Vertex('D')
        e = Vertex('E')
        f = Vertex('F')
        g = Vertex('G')
        h = Vertex('H')
        i = Vertex('I')
        j = Vertex('J')

        self.tree.addVertex(a)
        self.tree.addVertex(b)
        self.tree.addVertex(c)
        self.tree.addVertex(d)
        self.tree.addVertex(e)
        self.tree.addVertex(f)
        self.tree.addVertex(g)
        self.tree.addVertex(h)
        self.tree.addVertex(i)
        self.tree.addVertex(j)

        self.tree.addEdge(a, c)
        self.tree.addEdge(a, d)

        self.tree.addEdge(b, f)
        self.tree.addEdge(b, g)
        self.tree.addEdge(b, h)

        self.tree.addEdge(c, e)

        self.tree.addEdge(d, f)
        self.tree.addEdge(d, g)
        self.tree.addEdge(d, h)

        self.tree.addEdge(e, f)
        self.tree.addEdge(e, h)
        self.tree.addEdge(e, g)

        self.tree.addEdge(f, i)

        self.tree.addEdge(g, j)

    def tearDown(self):
        self.tree = None

    def test_edges(self):
        l = self.tree.verticesWithNoEdges()
        self.assertTrue( len( l ) == 3 )
        leafes = [x.name for x in l]
        self.assertTrue( ['H', 'I', 'J'] == leafes )

    def test_start_end_points(self):
        startPoints = []
        endPoints = []
        nameList = self.tree.getAllNames()

        for name in nameList:
            v = self.tree.getVertex(name)
            if self.tree.isStart(v):
                startPoints.append(v)
            if self.tree.isEnd(v):
                endPoints.append(v)

        self.assertTrue(len(startPoints) == 2)
        self.assertTrue(len(endPoints) == 3)

        starters = [x.name for x in startPoints]
        enders = [x.name for x in endPoints]

        self.assertTrue( starters == ['A', 'B'] )
        self.assertTrue( enders == ['H', 'I', 'J'] )


    def test_all_paths(self):
        pa = self.tree.find_all_paths('A', 'I')
        self.assertTrue( pa == [['A', 'C', 'E', 'F', 'I'], ['A', 'D', 'F', 'I']] )
        pa = self.tree.find_all_paths('A', 'J')
        self.assertTrue( pa == [['A', 'C', 'E', 'G', 'J'], ['A', 'D', 'G', 'J']] )
        pa = self.tree.find_all_paths('A', 'H')
        self.assertTrue( pa == [['A', 'C', 'E', 'H'], ['A', 'D', 'H']] )

        pa = self.tree.find_all_paths('B', 'I')
        self.assertTrue( pa == [['B', 'F', 'I']] )

        pa = self.tree.find_all_paths('B', 'J')
        self.assertTrue( pa == [['B', 'G', 'J']] )

        pa = self.tree.find_all_paths('B', 'H')
        self.assertTrue( pa == [['B', 'H']] )

    def test_couple_actions(self):
        aForA = Action( "//label[contains(@for,'isConstructionyes')]", 'CLICKABLE' )
        aForB = Action( "//label[contains(@for,'isConstructionno')]", 'CLICKABLE')
        aForC = Action( "//label[contains(@for,'hasBuildingPermityes')]", 'CLICKABLE')
        aForD = Action( "//label[contains(@for,'hasBuildingPermitno')]", 'CLICKABLE')
        aForE = Action("//input[@id='buildingPermitNumber']", 'TEXTABLE')
        aForF = Action("//label[contains(@for,'EXISTING_PROJECT')]", 'CLICKABLE')
        aForG = Action("//label[contains(@for,'NEW_PROJECT')]", 'CLICKABLE')
        aForH = Action("//label[contains(@for,'NO')]", 'CLICKABLE')
        aForI = Action("//select[@id='projectSelect']/option[contains(@value,'Project 2')]", 'CLICKABLE')
        aForJ = Action("//input[@id='projectName']", 'TEXTABLE')

        va = self.tree.getVertex('A')
        vb = self.tree.getVertex('B')
        vc = self.tree.getVertex('C')
        vd = self.tree.getVertex('D')
        ve = self.tree.getVertex('E')
        vf = self.tree.getVertex('F')
        vg = self.tree.getVertex('G')
        vh = self.tree.getVertex('H')
        vi = self.tree.getVertex('I')
        vj = self.tree.getVertex('J')

        va.addAction(aForA)
        vb.addAction(aForB)
        vc.addAction(aForC)
        vd.addAction(aForD)
        ve.addAction(aForE)
        vf.addAction(aForF)
        vg.addAction(aForG)
        vh.addAction(aForH)
        vi.addAction(aForI)
        vj.addAction(aForJ)

        nameList = self.tree.getAllNames()

        # check if the calls on action exists
        for name in nameList:
            a = self.tree.getVertex(name).getAction()
            a.getXpathStr()
            a.getElementType()

    def test_with_graph_file(self):
        with open("graph-screen-type.xml") as fp:
            soup = BeautifulSoup(fp, "lxml")
        for node in soup.find_all('node'):
            print( node['name'] )

        for edge in soup.find_all('edge'):
            print( "from =%s to=%s" % (edge['from'] ,edge['to'] ) )

        for action in soup.find_all('action'):
            print(action['xpath'])
            print(action['type'])
            print(action['nodename'])